# jmpy

![](https://img.shields.io/badge/python-3.0-brightgreen)

## 简介

将python代码一键加密为so或pyd。支持单个文件加密，整个项目加密

## 安装

    pip install jmpy3

## 使用方法

    jmpy -i "xxx project dir" [-o output dir]

加密后的文件默认存储在 dist/project_name/ 下